#!/usr/bin/env python
#
# Copyright (c) 2023-2024, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import os
import time
import subprocess
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES


class VMStat(CEPCollecting):
    def fill_results(self):
        res={}
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        while not succeed and retries < MAX_SCRIPT_RETRIES:
            try:
                proc = subprocess.Popen('cat /proc/vmstat', shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).stdout.readlines()
                for line in proc:
                    parameter=line.split()
                    if len(parameter)>1:
                        res[parameter[0]]=parameter[1]
                succeed = True
            except Exception as e:
                retries += 1
                succeed = False
                fail_reason = str(e)
                if retries >= MAX_SCRIPT_RETRIES:
                    break
                time.sleep(60 * 2 * retries)
            
        if not succeed:
            raise Exception("Unable to collect VMStat info: " + fail_reason)
        self.result["VMStat"]=res


def main():
    o = VMStat()
    o.run()


if __name__ == "__main__":
    main()
